# Scapy TUI

# SWEXML

[![Build](https://github.com/antoniovazquezblanco/scapy-tui/actions/workflows/build.yml/badge.svg)](https://github.com/antoniovazquezblanco/scapy-tui/actions/workflows/build.yml)
[![PyPI](https://img.shields.io/pypi/v/scapy-tui)](https://pypi.org/project/scapy-tui/)
[![Snyk](https://snyk.io/advisor/python/scapy-tui/badge.svg)](https://snyk.io/advisor/python/scapy-tui)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](LICENSE.md)

Browse network traffic and analyze packets in an interactive text-based user interface.

Just `pip install scapy-tui` and the `scapytui` command will be available.

![Scapy TUI screenshot](screenshot.svg)
